@@ -307,7 +307,8 @@ def _periods_for_range(start_date, end_date):
 def _period_for_week(year, week_number):
     """returns a pandas.Period for a given growing season year and week number"""
     first_sunday = _first_sunday(year)
-    return pandas.Period(first_sunday, freq='W-SAT') + week_number - 1
+    period = pandas.Period(first_sunday, freq='W-SAT') + week_number - 1
+    return period
 
 
 def _reindex_data(dataframe):
